Skip to content

Home > intention-kernel > AgentResponseFallbacks

AgentResponseFallbacks interface ​

Host-authored safe copy used only when a model cannot ground a control response.

Signature:

typescript
export interface AgentResponseFallbacks

Properties ​

Property

Modifiers

Type

Description

unsupportedIntention?

readonly

string

(Optional) Response for an intention that no registered capability can represent.