Skip to content

Home > intention-kernel > CapabilityGuidance

CapabilityGuidance interface ​

Model-facing semantic guidance attached to one capability contract.

Signature:

typescript
export interface CapabilityGuidance

Properties ​

Property

Modifiers

Type

Description

examples

readonly

readonly string[]

Representative utterances used only as semantic examples.

whenNotToUse

readonly

readonly string[]

Situations that resemble this operation but must not select it.

whenToUse

readonly

readonly string[]

Situations in which this capability is an appropriate operation.