Skip to content

Home > intention-kernel > CapabilityIssue

CapabilityIssue interface ​

Expected domain failure that is safe to expose through the response composer.

Signature:

typescript
export interface CapabilityIssue

Properties ​

Property

Modifiers

Type

Description

code

readonly

string

Stable machine-readable domain code.

details?

readonly

Readonly<Record<string, unknown>>

(Optional) Optional sanitized domain metadata.

message

readonly

string

Safe explanation available to the response composer.

retryable

readonly

boolean

Whether a later user or infrastructure retry may be meaningful.