Skip to content

Home > intention-kernel > CapabilityReferenceRequirements

CapabilityReferenceRequirements interface ​

Model-reference requirements for capabilities that operate on active server-owned choices.

Signature:

typescript
export interface CapabilityReferenceRequirements

Properties ​

Property

Modifiers

Type

Description

maximum

readonly

number

Maximum number of distinct option targets accepted for execution.

minimum

readonly

number

Minimum number of distinct option targets required for execution.

source

readonly

"active_interaction_options"

Authoritative target set exposed to the model for reference resolution.