Skip to content

Home > intention-kernel > DurableTurnScope

DurableTurnScope interface ​

Scope held while one thread is serialized by a durability adapter.

Signature:

typescript
export interface DurableTurnScope

Properties ​

Property

Modifiers

Type

Description

checkpoint

readonly

KernelCheckpoint | null

Latest checkpoint loaded while holding the thread lease.

priorResult

readonly

DurableTurnResult | null

Previously committed value for the same turn identity, when duplicated.

Methods ​

Method

Description

commit(result, outbox)

Atomically store the turn result, checkpoint and optional event outbox.

runEffect(effect, operation)

Coordinate and durably record one potentially external effect.