Skip to content

Home > intention-kernel > FactDeclaration

FactDeclaration interface ​

Fact a capability promises to publish.

Signature:

typescript
export interface FactDeclaration extends FactReference

Extends: FactReference

Properties ​

Property

Modifiers

Type

Description

deriveModelRedactions?

readonly

(value: unknown) => readonly string[]

(Optional) Sensitive string values that must be removed from later model context.

modelVisibility?

readonly

FactModelVisibility

(Optional) Degree to which the confirmed value may be shown to model tasks.