Skip to content

Home > intention-kernel > IntentionKernelError

IntentionKernelError class ​

Base class for exceptional failures exposed by Intention Kernel.

Signature:

typescript
export declare class IntentionKernelError extends Error

Extends: Error

Constructors ​

Constructor

Modifiers

Description

(constructor)(options)

Constructs a new instance of the IntentionKernelError class

Properties ​

Property

Modifiers

Type

Description

code

readonly

string

Stable machine-readable failure code.

context

readonly

ErrorContext

Frozen JSON-safe diagnostic metadata.

retryable

readonly

boolean

Whether a host retry can be safe and meaningful.

Methods ​

Method

Modifiers

Description

toJSON()

Return only stable, sanitized fields suitable for logs or HTTP responses.