Skip to content

Home > intention-kernel > InteractionOption

InteractionOption interface ​

Server-owned selectable option.

Signature:

typescript
export interface InteractionOption

Properties ​

Property

Modifiers

Type

Description

id

readonly

string

Stable identifier returned by a clicked selection.

label

readonly

string

User-visible option text.

referenceExamples?

readonly

readonly string[]

(Optional) Optional exact reference examples, never selection authority or defaults.

targetCapabilityId?

readonly

CapabilityId

(Optional) Capability authorized to consume this option, when it differs from the interaction owner.

value

readonly

unknown

Trusted structured value recovered by the kernel.