Skip to content

Home > intention-kernel > ModelGuidancePolicyMatch

ModelGuidancePolicyMatch interface ​

Result of evaluating one host-owned contextual guidance selector.

Signature:

typescript
export interface ModelGuidancePolicyMatch

Properties ​

Property

Modifiers

Type

Description

matchedSelectors

readonly

readonly string[]

Stable selector names that explain why the policy matched.

selected

readonly

boolean

Whether the policy copy should be projected for the current turn.