Skip to content

Home > intention-kernel > ResponseBrief > canonicalFallback

ResponseBrief.canonicalFallback property ​

Validated copy for a single completed capability, all authored current-turn results when any is required, or a server-owned interaction goal. Required invitations follow completed results; optional invitations may be omitted.

Signature:

typescript
readonly canonicalFallback?: CanonicalResponse;