Home > intention-kernel > CapabilityEventOptions
CapabilityEventOptions interface
Metadata accepted when a capability exposes observable domain progress.
Signature:
typescript
export interface CapabilityEventOptions1
Properties
Property | Modifiers | Type | Description |
|---|---|---|---|
| "trace" | "audit" | "integration" | (Optional) Event classification used by sinks to route traces, audits and integrations. |