Home > intention-kernel > DurableTurnScope
DurableTurnScope interface
Scope held while one thread is serialized by a durability adapter.
Signature:
typescript
export interface DurableTurnScopeProperties
Property | Modifiers | Type | Description |
|---|---|---|---|
| KernelCheckpoint | null | Latest checkpoint loaded while holding the thread lease. | |
| DurableTurnResult | null | Previously committed value for the same turn identity, when duplicated. |
Methods
Method | Description |
|---|---|
Atomically store the turn result, checkpoint and optional event outbox. | |
Coordinate and durably record one potentially external effect. |