Home > intention-kernel > FactDeclaration
FactDeclaration interface
Fact a capability promises to publish.
Signature:
typescript
export interface FactDeclaration extends FactReferenceExtends: FactReference
Properties
Property | Modifiers | Type | Description |
|---|---|---|---|
| (value: unknown) => readonly string[] | (Optional) Sensitive string values that must be removed from later model context. | |
| (Optional) Degree to which the confirmed value may be shown to model tasks. |